@@ -3,8 +3,9 @@ Main interface for cloudfront service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.cloudfront import (
+    from mypy_boto3_cloudfront import (
         Client,
         CloudFrontClient,
         DistributionDeployedWaiter,
@@ -14,7 +15,7 @@ Usage::
         ListInvalidationsPaginator,
         ListStreamingDistributionsPaginator,
         StreamingDistributionDeployedWaiter,
-        )
+    )
 
     session = boto3.Session()
 
@@ -29,8 +30,9 @@ Usage::
     list_distributions_paginator: ListDistributionsPaginator = client.get_paginator("list_distributions")
     list_invalidations_paginator: ListInvalidationsPaginator = client.get_paginator("list_invalidations")
     list_streaming_distributions_paginator: ListStreamingDistributionsPaginator = client.get_paginator("list_streaming_distributions")
+    ```
 """
-from mypy_boto3_cloudfront.client import CloudFrontClient as Client, CloudFrontClient
+from mypy_boto3_cloudfront.client import CloudFrontClient
 from mypy_boto3_cloudfront.paginator import (
     ListCloudFrontOriginAccessIdentitiesPaginator,
     ListDistributionsPaginator,
@@ -43,6 +45,8 @@ from mypy_boto3_cloudfront.waiter import (
     StreamingDistributionDeployedWaiter,
 )
 
+Client = CloudFrontClient
+
 
 __all__ = (
     "Client",
