@@ -1114,7 +1114,7 @@ ViewerCertificateTypeDef = TypedDict(
         "ACMCertificateArn": str,
         "SSLSupportMethod": Literal["sni-only", "vip"],
         "MinimumProtocolVersion": Literal[
-            "SSLv3", "TLSv1", "TLSv1_2016", "TLSv1.1_2016", "TLSv1.2_2018"
+            "SSLv3", "TLSv1", "TLSv1_2016", "TLSv1.1_2016", "TLSv1.2_2018", "TLSv1.2_2019"
         ],
         "Certificate": str,
         "CertificateSource": Literal["cloudfront", "iam", "acm"],
